package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.system.mapper.VipUserMapper;
import com.ruoyi.system.domain.VipUser;
import com.ruoyi.system.service.IVipUserService;

/**
 * viplistService业务层处理
 * 
 * @author ruoyi
 * @date 2023-05-24
 */
@Service
public class VipUserServiceImpl extends ServiceImpl<BaseMapper<VipUser>,VipUser> implements IVipUserService
{
    @Autowired
    private VipUserMapper vipUserMapper;

    /**
     * 查询viplist
     * 
     * @param id viplist主键
     * @return viplist
     */
    @Override
    public VipUser selectVipUserById(Long id)
    {
        return vipUserMapper.selectVipUserById(id);
    }

    /**
     * 查询viplist列表
     * 
     * @param vipUser viplist
     * @return viplist
     */
    @Override
    public List<VipUser> selectVipUserList(VipUser vipUser)
    {
        return vipUserMapper.selectVipUserList(vipUser);
    }

    /**
     * 新增viplist
     * 
     * @param vipUser viplist
     * @return 结果
     */
    @Override
    public int insertVipUser(VipUser vipUser)
    {
        return vipUserMapper.insertVipUser(vipUser);
    }

    /**
     * 修改viplist
     * 
     * @param vipUser viplist
     * @return 结果
     */
    @Override
    public int updateVipUser(VipUser vipUser)
    {
        return vipUserMapper.updateVipUser(vipUser);
    }

    /**
     * 批量删除viplist
     * 
     * @param ids 需要删除的viplist主键
     * @return 结果
     */
    @Override
    public int deleteVipUserByIds(Long[] ids)
    {
        return vipUserMapper.deleteVipUserByIds(ids);
    }

    /**
     * 删除viplist信息
     * 
     * @param id viplist主键
     * @return 结果
     */
    @Override
    public int deleteVipUserById(Long id)
    {
        return vipUserMapper.deleteVipUserById(id);
    }
}
